=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2014-01-27 14:50:56 +0000
+++ CMakeLists.txt	2014-02-24 13:33:41 +0000
@@ -11,7 +11,7 @@
 set(DESKTOP_FILE "${PROJECT_NAME}_${APP_NAME}.desktop")
 set(URLS_FILE "${PROJECT_NAME}_${APP_NAME}.url-dispatcher")
 set(MAIN_QML calendar.qml)
-set(ICON calendar64.png)
+set(ICON_FILE calendar-app@30.png)
 set(AUTOPILOT_DIR calendar_app)
 set(APP_HARDCODE calendar-app)
 
@@ -23,13 +23,14 @@
     set(CMAKE_INSTALL_PREFIX /)
     set(CMAKE_INSTALL_BINDIR /)
 	set(DATA_DIR /)
+	set (ICON ${ICON_FILE})
 	set(EXEC "qmlscene %u ${MAIN_QML}")
 	set(DESKTOP_DIR ${DATA_DIR})
 	set(URLS_DIR ${DATA_DIR})
 else(CLICK_MODE)
 	set(DATA_DIR ${CMAKE_INSTALL_DATADIR}/${APP_HARDCODE})
 	set(EXEC ${APP_HARDCODE})
-	set(ICON ${CMAKE_INSTALL_PREFIX}/${DATA_DIR}/${ICON})
+	set(ICON ${CMAKE_INSTALL_PREFIX}/${DATA_DIR}/${ICON_FILE})
 	configure_file(${APP_HARDCODE}.in
 		${CMAKE_CURRENT_BINARY_DIR}/${APP_HARDCODE})
 	install(PROGRAMS ${CMAKE_CURRENT_BINARY_DIR}/${APP_HARDCODE}
@@ -46,8 +47,8 @@
 
 file(GLOB SRC_FILES
      RELATIVE ${CMAKE_CURRENT_SOURCE_DIR}
-     *.qml *.js *.png *.js)
-install(FILES ${SRC_FILES}  DESTINATION ${DATA_DIR})
+     *.qml *.js *.png *.js *.svg)
+install(FILES ${SRC_FILES} ${ICON_FILE} DESTINATION ${DATA_DIR})
 
 configure_file(${DESKTOP_FILE}.in ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE})
 install(FILES ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE} DESTINATION ${DESKTOP_DIR})

=== added file 'Defines.js'
--- Defines.js	1970-01-01 00:00:00 +0000
+++ Defines.js	2014-02-08 05:52:55 +0000
@@ -0,0 +1,54 @@
+.pragma library
+
+.import QtOrganizer 5.0 as QtPim
+
+var reminderLabel = getReminderLabels();
+//value in seconds
+var reminderValue = [ 0,
+    300 /*5 * 60*/,
+    900 /*15* 60*/,
+    1800 /*30* 60*/,
+    3600 /*1*60*60*/,
+    7200 /*2*60*60*/,
+    86400 /*24*60*60*/,
+    172800 /*2*24*60*60*/,
+    604800 /*7*24*60*60*/,
+    1209600 /*14*24*60*60*/];
+
+var recurrenceLabel = getRecurrenceLabels();
+var recurrenceValue = [ QtPim.RecurrenceRule.Invalid,
+    QtPim.RecurrenceRule.Daily,
+    QtPim.RecurrenceRule.Weekly,
+    QtPim.RecurrenceRule.Monthly,
+    QtPim.RecurrenceRule.Yearly];
+
+function getReminderLabels() {
+    var object = Qt.createQmlObject('\
+        import QtQuick 2.0;\
+        import Ubuntu.Components 0.1;\
+        QtObject {\
+            property var reminderLabel:[i18n.tr("No Reminder"),\
+                i18n.tr("5 minutes"),\
+                i18n.tr("15 minutes"),\
+                i18n.tr("30 minutes"),\
+                i18n.tr("1 hour"),\
+                i18n.tr("2 hours"),\
+                i18n.tr("1 day"),\
+                i18n.tr("2 days"),\
+                i18n.tr("1 week"),\
+                i18n.tr("2 weeks")];}', Qt.application, 'ReminderLabelObj');
+    return object.reminderLabel;
+}
+
+function getRecurrenceLabels() {
+    var object = Qt.createQmlObject('\
+        import QtQuick 2.0;\
+        import Ubuntu.Components 0.1;\
+        QtObject {\
+            property var recurrenceLabel:[i18n.tr("Once"),\
+                i18n.tr("Daily"),\
+                i18n.tr("Weekly"),\
+                i18n.tr("Monthly"),\
+                i18n.tr("Yearly")];}', Qt.application, 'RecurrenceLabelObj');
+    return object.recurrenceLabel;
+}

=== modified file 'EventDetails.qml'
--- EventDetails.qml	2014-01-30 15:27:40 +0000
+++ EventDetails.qml	2014-02-27 15:09:06 +0000
@@ -3,8 +3,10 @@
 import Ubuntu.Components.Popups 0.1
 import Ubuntu.Components.ListItems 0.1
 import Ubuntu.Components.Themes.Ambiance 0.1
+import QtOrganizer 5.0
 
 import "GlobalEventModel.js" as GlobalModel
+import "Defines.js" as Defines
 
 Page {
     id: root
@@ -33,8 +35,6 @@
         }
     }
     function showEvent(e) {
-        var location = "";
-
         // TRANSLATORS: this is a time formatting string,
         // see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
         var timeFormat = i18n.tr("hh:mm");
@@ -48,6 +48,8 @@
         if( e.displayLabel) {
             titleLabel.text = e.displayLabel;
         }
+
+        var location = "";
         if( e.location ) {
             locationLabel.text = e.location;
             location = e.location;
@@ -62,6 +64,24 @@
                 contactModel.append( {"name": attendees[j].name } );
             }
         }
+
+        var index = 0;
+        if(e.recurrence ) {
+            var recurrenceRule = e.recurrence.recurrenceRules;
+            index = ( recurrenceRule.length > 0 ) ? recurrenceRule[0].frequency : 0;
+        }
+        recurrentHeader.value = Defines.recurrenceLabel[index];
+
+        index = 0;
+        var reminder = e.detail( Detail.VisualReminder);
+        if( reminder ) {
+            var reminderTime = reminder.secondsBeforeStart;
+            var foundIndex = Defines.reminderValue.indexOf(reminderTime);
+            index = foundIndex != -1 ? foundIndex : 0;
+        }
+        reminderHeader.value = Defines.reminderLabel[index];
+
+
         // FIXME: need to cache map image to avoid duplicate download every time
         var imageSrc = "http://maps.googleapis.com/maps/api/staticmap?center="+location+
                 "&markers=color:red|"+location+"&zoom=15&size="+mapContainer.width+
@@ -214,7 +234,6 @@
                 id: reminderHeader
                 xMargin: column.recurranceAreaMaxWidth
                 header: i18n.tr("Remind me")
-                value :"15 minutes before" //Neds to change
             }
         }
     }

=== modified file 'EventListModel.qml'
--- EventListModel.qml	2013-10-17 12:52:23 +0000
+++ EventListModel.qml	2014-02-26 13:42:20 +0000
@@ -6,6 +6,7 @@
 OrganizerModel {
     id: eventModel
     manager:"eds"
+    autoUpdate: false
 
     signal reloaded
 

=== modified file 'MonthView.qml'
--- MonthView.qml	2014-01-25 03:19:04 +0000
+++ MonthView.qml	2014-02-27 15:09:06 +0000
@@ -16,7 +16,7 @@
     PathViewBase{
         id: monthViewPath
 
-        property var startMonth: addMonth(currentMonth,-1);
+        property var startMonth: currentMonth;
 
         anchors.top:parent.top
 
@@ -46,6 +46,8 @@
         }
 
         delegate: MonthComponent{
+            property bool isCurrentItem: index === monthViewPath.currentIndex
+
             width: parent.width - units.gu(5)
             height: parent.height - units.gu(5)
 
@@ -56,7 +58,7 @@
                 case 0:
                     return monthViewPath.startMonth;
                 case -1:
-                    return monthViewPath.addMonth(monthViewPath.startMonth,2);
+                    return monthViewPath.addMonth(monthViewPath.startMonth,-1);
                 case 1:
                     return monthViewPath.addMonth(monthViewPath.startMonth,1);
                 }

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2014-01-25 03:19:04 +0000
+++ NewEvent.qml	2014-02-27 15:09:06 +0000
@@ -1,10 +1,13 @@
 import QtQuick 2.0
+import QtOrganizer 5.0
 import Ubuntu.Components 0.1
 import Ubuntu.Components.Popups 0.1
 import Ubuntu.Components.ListItems 0.1
 import Ubuntu.Components.Themes.Ambiance 0.1
+import QtOrganizer 5.0
 
 import "GlobalEventModel.js" as GlobalModel
+import "Defines.js" as Defines
 
 Page {
     id: root
@@ -43,6 +46,7 @@
             editEvent(event);
         }
     }
+
     //Data for Add events
     function addEvent() {
         event = Qt.createQmlObject("import QtOrganizer 5.0; Event { }", Qt.application,"NewEvent.qml");
@@ -53,16 +57,20 @@
         startTime.text = Qt.formatDateTime(startDate, "dd MMM yyyy hh:mm");
         endTime.text = Qt.formatDateTime(endDate, "dd MMM yyyy hh:mm");
     }
+
     //Editing Event
     function editEvent(e) {
         startDate =new Date(e.startDateTime);
         endDate = new Date(e.endDateTime);
         startTime.text = Qt.formatDateTime(e.startDateTime, "dd MMM yyyy hh:mm");
         endTime.text = Qt.formatDateTime(e.endDateTime, "dd MMM yyyy hh:mm");
-        if(e.displayLabel)
+
+        if(e.displayLabel) {
             titleEdit.text = e.displayLabel;
-        if(e.location)
+        }
+        if(e.location) {
             locationEdit.text = e.location;
+        }
         if( e.description ) {
             messageEdit.text = e.description;
         }
@@ -73,7 +81,24 @@
                     personEdit.text += ",";
             }
         }
+
+        var index = 0;
+        if(e.recurrence ) {
+            var recurrenceRule = e.recurrence.recurrenceRules;
+            index = ( recurrenceRule.length > 0 ) ? recurrenceRule[0].frequency : 0;
+        }
+        recurrenceOption.selectedIndex = index;
+
+        index = 0;
+        var reminder = e.detail( Detail.VisualReminder);
+        if( reminder ) {
+            var reminderTime = reminder.secondsBeforeStart;
+            var foundIndex = Defines.reminderValue.indexOf(reminderTime);
+            index = foundIndex != -1 ? foundIndex : 0;
+        }
+        reminderOption.selectedIndex = index;
     }
+
     //Save the new or Existing event
     function saveToQtPim() {
         internal.clearFocus()
@@ -85,12 +110,48 @@
             event.displayLabel = titleEdit.text;
             event.description = messageEdit.text;
             event.location = locationEdit.text
+
             event.attendees = []; // if Edit remove all attendes & add them again if any
             if( personEdit.text != "") {
-                var attendee = Qt.createQmlObject("import QtOrganizer 5.0; EventAttendee{}", Qt.application, "NewEvent.qml");
+                var attendee = Qt.createQmlObject("import QtOrganizer 5.0; EventAttendee{}", event, "NewEvent.qml");
                 attendee.name = personEdit.text;
                 event.setDetail(attendee);
             }
+
+            var recurrenceRule = Defines.recurrenceValue[ recurrenceOption.selectedIndex ];
+            if( recurrenceRule !== RecurrenceRule.Invalid ) {
+                var rule = Qt.createQmlObject("import QtOrganizer 5.0; RecurrenceRule {}", event.recurrence,"NewEvent.qml");
+                rule.frequency = recurrenceRule;
+                event.recurrence.recurrenceRules = [rule];
+            }
+
+            //remove old reminder value
+            var oldVisualReminder = event.detail(Detail.VisualReminder);
+            if(oldVisualReminder) {
+                event.removeDetail(oldVisualReminder);
+            }
+
+            var oldAudibleReminder = event.detail(Detail.AudibleReminder);
+            if(oldAudibleReminder) {
+                event.removeDetail(oldAudibleReminder);
+            }
+
+            var reminderTime = Defines.reminderValue[ reminderOption.selectedIndex ];
+            if( reminderTime !== 0 ) {
+                var visualReminder =  Qt.createQmlObject("import QtOrganizer 5.0; VisualReminder{}", event, "NewEvent.qml");
+                visualReminder.repetitionCount = 3;
+                visualReminder.repetitionDelay = 120;
+                visualReminder.message = titleEdit.text
+                visualReminder.secondsBeforeStart = reminderTime;
+                event.setDetail(visualReminder);
+
+                var audibleReminder =  Qt.createQmlObject("import QtOrganizer 5.0; AudibleReminder{}", event, "NewEvent.qml");
+                audibleReminder.repetitionCount = 3;
+                audibleReminder.repetitionDelay = 120;
+                audibleReminder.secondsBeforeStart = reminderTime;
+                event.setDetail(audibleReminder);
+            }
+
             internal.eventModel.saveItem(event);
             pageStack.pop();
         }
@@ -278,40 +339,35 @@
 
             Item {
                 width: parent.width
-                height: childrenRect.height
+                height: recurrenceOption.height
                 Label{
                     id: frequencyLabel
                     text: i18n.tr("This happens");
                     anchors.verticalCenter: parent.verticalCenter
                 }
                 OptionSelector{
+                    id: recurrenceOption
                     anchors.right: parent.right
                     width: parent.width - optionSelectorWidth - units.gu(1)
-                    model:[i18n.tr("Once"),i18n.tr("Daily"),i18n.tr("Weekly"),i18n.tr("Monthly"),i18n.tr("Yearly")]
+                    model: Defines.recurrenceLabel
+                    containerHeight: itemHeight * 4
                 }
             }
 
             Item{
                 width: parent.width
-                height: childrenRect.height
+                height: reminderOption.height
                 Label{
                     id: remindLabel
                     text: i18n.tr("Remind me");
                     anchors.verticalCenter: parent.verticalCenter
                 }
                 OptionSelector{
+                    id: reminderOption
                     anchors.right: parent.right
                     width: parent.width - optionSelectorWidth - units.gu(1)
-                    model:[i18n.tr("No Reminder"),
-                        i18n.tr("5 minutes"),
-                        i18n.tr("15 minutes"),
-                        i18n.tr("30 minutes"),
-                        i18n.tr("1 hour"),
-                        i18n.tr("2 hours"),
-                        i18n.tr("1 day"),
-                        i18n.tr("2 days"),
-                        i18n.tr("1 week"),
-                        i18n.tr("2 weeks")]
+                    containerHeight: itemHeight * 4
+                    model: Defines.reminderLabel
                 }
             }
         }

=== modified file 'PathViewBase.qml'
--- PathViewBase.qml	2014-01-25 03:19:04 +0000
+++ PathViewBase.qml	2014-02-27 15:09:06 +0000
@@ -12,11 +12,12 @@
     signal scrollUp();
     signal scrollDown();
 
+    preferredHighlightBegin: 0.5
+    preferredHighlightEnd: 0.5
+
     path: Path {
-        startX: -(root.width/2); startY: root.height/2
-        PathLine { relativeX: root.width; relativeY: 0 }
-        PathLine { relativeX: root.width; relativeY: 0 }
-        PathLine { relativeX: root.width; relativeY: 0 }
+        startX: -(root.width); startY: root.height/2
+        PathLine { x: (root.width)*2  ; relativeY: 0;  }
     }
 
     // 0= current index, -1= previous index, 1 next index

=== modified file 'TimeLineHeader.qml'
--- TimeLineHeader.qml	2013-09-28 09:37:52 +0000
+++ TimeLineHeader.qml	2014-01-31 01:09:36 +0000
@@ -64,7 +64,7 @@
             case 0:
                 return date;
             case -1:
-                return date.addDays(14);
+                return date.addDays(-7);
             case 1:
                 return date.addDays(7);
             }

=== modified file 'WeekView.qml'
--- WeekView.qml	2014-01-30 15:27:40 +0000
+++ WeekView.qml	2014-02-27 15:09:06 +0000
@@ -33,7 +33,7 @@
         id: weekViewPath
 
         property var visibleWeek: dayStart.weekStart(Qt.locale().firstDayOfWeek);
-        property var weekStart: weekViewPath.visibleWeek.addDays(-7)
+        property var weekStart: weekViewPath.visibleWeek
 
         width: parent.width
         height: root.height - weekViewPath.y
@@ -71,7 +71,7 @@
                     return weekViewPath.weekStart;
                 case -1:
                     var weekStartDay= weekViewPath.weekStart.weekStart(Qt.locale().firstDayOfWeek);
-                    return weekStartDay.addDays(14);
+                    return weekStartDay.addDays(-7);
                 case 1:
                     var weekStartDay = weekViewPath.weekStart.weekStart(Qt.locale().firstDayOfWeek);
                     return weekStartDay.addDays(7);

=== modified file 'YearView.qml'
--- YearView.qml	2014-01-30 15:24:34 +0000
+++ YearView.qml	2014-02-27 15:09:06 +0000
@@ -25,26 +25,22 @@
         return new Date(year,0,1,0,0,0,0);
     }
 
-    QtObject{
-        id: intern
-        property var startYear: getDateFromYear(currentYear.getFullYear()-1);        
-    }
-
     delegate: GridView{
         id: yearView
         clip: true
 
         property int scrollMonth: 0;
+        property bool isCurrentItem: index == root.currentIndex
         property var year: getYear();
 
         function getYear() {
             switch( root.indexType(index)) {
             case 0:
-                return intern.startYear;
+                return currentYear;
             case -1:
-                return getDateFromYear(intern.startYear.getFullYear() + 2);
+                return getDateFromYear(currentYear.getFullYear() - 1);
             case 1:
-                return getDateFromYear(intern.startYear.getFullYear() + 1);
+                return getDateFromYear(currentYear.getFullYear() + 1);
             }
         }
 
@@ -52,23 +48,13 @@
         height: parent.height
         anchors.top: parent.top
 
-        cellWidth: width/2
+        readonly property int minCellWidth: units.gu(30)
+        cellWidth: Math.floor(Math.min.apply(Math, [3, 4].map(function(n)
+            { return ((width / n >= minCellWidth) ? width / n : width / 2) })))
+
         cellHeight: cellWidth * 1.4
 
-        function getCellWidth() {
-            if( yearView.width/2  < units.gu(40)) {
-                return yearView.width/2
-            } else {
-                for(var i = 4 ; i > 2; --i) {
-                    if( yearView.width/i > units.gu(35)) {
-                        return yearView.width/i
-                    }
-                }
-            }
-        }
-
         model: 12 /* months in a year */
-        snapMode: GridView.SnapOneRow
 
         onYearChanged : {
             scrollMonth=0;

=== renamed file 'calendar64.png' => 'calendar-app@30.png'
Binary files calendar64.png and calendar-app@30.png differ
=== modified file 'calendar.qml'
--- calendar.qml	2014-01-30 15:24:34 +0000
+++ calendar.qml	2014-02-27 15:09:06 +0000
@@ -94,6 +94,9 @@
                 if(globalModel) {
                     globalModel.startPeriod =  new Date(currentDay.getFullYear(),0,1,0,0,0,0);
                     globalModel.endPeriod = new Date(currentDay.getFullYear(),11,31,0,0,0,0);
+                    // only enable auto update after set the date interval
+	            globalModel.autoUpdate = true
+	            globalModel.update()
                 }
             }
 

=== modified file 'com.ubuntu.calendar_calendar.desktop.in'
--- com.ubuntu.calendar_calendar.desktop.in	2014-01-18 23:29:11 +0000
+++ com.ubuntu.calendar_calendar.desktop.in	2014-02-17 18:41:03 +0000
@@ -6,5 +6,4 @@
 Icon=@ICON@
 Name=Calendar
 X-Ubuntu-Touch=true
-X-Ubuntu-StageHint=SideStage
 X-Ubuntu-Gettext-Domain=@PROJECT_NAME@

=== modified file 'debian/changelog'
--- debian/changelog	2014-01-18 23:29:11 +0000
+++ debian/changelog	2014-02-24 13:36:54 +0000
@@ -1,7 +1,17 @@
-calendar-app (0.4ubuntu1) UNRELEASED; urgency=medium
+calendar-app (0.5) UNRELEASED; urgency=medium
 
+  [ Sergio Schvezov ]
   * Adding cmake 
 
+  [ David Planella  ]
+  * Fix app icon not included in the package.
+
+  [ Alan Pope ]
+  * Remove side-stage hint (LP: #1281236)
+
+  [ Dimitri John Ledkov ]
+  * Ship *.svg assets in click-buddy/cmake build.
+
  -- Sergio Schvezov <sergio.schvezov@canonical.com>  Sat, 18 Jan 2014 17:05:03 -0300
 
 calendar-app (0.4) raring; urgency=low

=== modified file 'po/ar.po'
--- po/ar.po	2013-12-03 06:16:42 +0000
+++ po/ar.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ast.po'
--- po/ast.po	2014-01-15 06:22:22 +0000
+++ po/ast.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
-"X-Generator: Launchpad (build 16890)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/az.po'
--- po/az.po	2013-12-03 06:16:42 +0000
+++ po/az.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/be.po'
--- po/be.po	2013-12-03 06:16:42 +0000
+++ po/be.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/bg.po'
--- po/bg.po	2014-01-26 05:15:56 +0000
+++ po/bg.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-26 05:15+0000\n"
-"X-Generator: Launchpad (build 16914)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== added file 'po/br.po'
--- po/br.po	1970-01-01 00:00:00 +0000
+++ po/br.po	2014-02-17 06:03:42 +0000
@@ -0,0 +1,133 @@
+# Breton translation for ubuntu-calendar-app
+# Copyright (c) 2014 Rosetta Contributors and Canonical Ltd 2014
+# This file is distributed under the same license as the ubuntu-calendar-app package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2014.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: ubuntu-calendar-app\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-02-16 07:46+0000\n"
+"Last-Translator: Rouxel <vincent.rouxel@mailoo.org>\n"
+"Language-Team: Breton <br@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2014-02-17 06:03+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../EventBubble.qml:38
+msgid "hh:mm"
+msgstr ""
+
+#. TRANSLATORS: the first argument (%1) refers to a start time for an event,
+#. while the second one (%2) refers to the end time
+#: ../EventBubble.qml:43
+#, qt-format
+msgid "%1 - %2"
+msgstr ""
+
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr ""
+
+#: ../EventDetails.qml:79
+msgid "Edit"
+msgstr ""
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "ouzhpenan anv an darvoud"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "lec'h ha tud"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Fazi"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Mat eo"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Enrollañ"
+
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
+msgstr ""
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../TimeLineBackground.qml:18
+msgid "hh ap"
+msgstr ""
+
+#: ../TimePicker.qml:23
+msgid "Time"
+msgstr ""
+
+#: ../TimePicker.qml:49
+msgid "Hour"
+msgstr "Eur"
+
+#: ../TimePicker.qml:63
+msgid "Minute"
+msgstr "Minutenn"
+
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "Nullañ"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
+msgid "Today"
+msgstr ""
+
+#: ../calendar.qml:75
+msgid "Year"
+msgstr ""
+
+#: ../calendar.qml:95
+msgid "Month"
+msgstr ""
+
+#: ../calendar.qml:108
+msgid "Week"
+msgstr ""
+
+#: ../calendar.qml:124
+msgid "Day"
+msgstr ""
+
+#: ../.build/calendar-app.desktop.js:1
+msgid "Calendar"
+msgstr ""

=== modified file 'po/ca.po'
--- po/ca.po	2013-12-03 06:16:42 +0000
+++ po/ca.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== added file 'po/ckb.po'
--- po/ckb.po	1970-01-01 00:00:00 +0000
+++ po/ckb.po	2014-02-25 06:24:33 +0000
@@ -0,0 +1,133 @@
+# Kurdish (Sorani) translation for ubuntu-calendar-app
+# Copyright (c) 2014 Rosetta Contributors and Canonical Ltd 2014
+# This file is distributed under the same license as the ubuntu-calendar-app package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2014.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: ubuntu-calendar-app\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-02-24 16:32+0000\n"
+"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"Language-Team: Kurdish (Sorani) <ckb@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2014-02-25 06:24+0000\n"
+"X-Generator: Launchpad (build 16926)\n"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../EventBubble.qml:38
+msgid "hh:mm"
+msgstr ""
+
+#. TRANSLATORS: the first argument (%1) refers to a start time for an event,
+#. while the second one (%2) refers to the end time
+#: ../EventBubble.qml:43
+#, qt-format
+msgid "%1 - %2"
+msgstr ""
+
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr ""
+
+#: ../EventDetails.qml:79
+msgid "Edit"
+msgstr ""
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr ""
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr ""
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr ""
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr ""
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr ""
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr ""
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr ""
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr ""
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr ""
+
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
+msgstr ""
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../TimeLineBackground.qml:18
+msgid "hh ap"
+msgstr ""
+
+#: ../TimePicker.qml:23
+msgid "Time"
+msgstr ""
+
+#: ../TimePicker.qml:49
+msgid "Hour"
+msgstr ""
+
+#: ../TimePicker.qml:63
+msgid "Minute"
+msgstr ""
+
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr ""
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr ""
+
+#: ../calendar.qml:64
+msgid "Today"
+msgstr ""
+
+#: ../calendar.qml:75
+msgid "Year"
+msgstr ""
+
+#: ../calendar.qml:95
+msgid "Month"
+msgstr ""
+
+#: ../calendar.qml:108
+msgid "Week"
+msgstr ""
+
+#: ../calendar.qml:124
+msgid "Day"
+msgstr ""
+
+#: ../.build/calendar-app.desktop.js:1
+msgid "Calendar"
+msgstr ""

=== modified file 'po/cs.po'
--- po/cs.po	2014-01-08 05:40:50 +0000
+++ po/cs.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-08 05:40+0000\n"
-"X-Generator: Launchpad (build 16877)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/cy.po'
--- po/cy.po	2013-12-03 06:16:42 +0000
+++ po/cy.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/de.po'
--- po/de.po	2013-12-03 06:16:42 +0000
+++ po/de.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/en_AU.po'
--- po/en_AU.po	2013-12-03 06:16:42 +0000
+++ po/en_AU.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/en_CA.po'
--- po/en_CA.po	2013-12-03 06:16:42 +0000
+++ po/en_CA.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2013-12-03 06:16:42 +0000
+++ po/en_GB.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/eo.po'
--- po/eo.po	2013-12-03 06:16:42 +0000
+++ po/eo.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/es.po'
--- po/es.po	2014-01-15 06:22:22 +0000
+++ po/es.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
-"X-Generator: Launchpad (build 16890)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/et.po'
--- po/et.po	2013-12-03 06:16:42 +0000
+++ po/et.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/fa.po'
--- po/fa.po	2013-12-03 06:16:42 +0000
+++ po/fa.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/fi.po'
--- po/fi.po	2013-12-03 06:16:42 +0000
+++ po/fi.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/fr.po'
--- po/fr.po	2013-12-03 06:16:42 +0000
+++ po/fr.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/gd.po'
--- po/gd.po	2013-12-03 06:16:42 +0000
+++ po/gd.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/gl.po'
--- po/gl.po	2013-12-03 06:16:42 +0000
+++ po/gl.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/gu.po'
--- po/gu.po	2013-12-03 06:16:42 +0000
+++ po/gu.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/he.po'
--- po/he.po	2013-12-03 06:16:42 +0000
+++ po/he.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/hi.po'
--- po/hi.po	2013-12-03 06:16:42 +0000
+++ po/hi.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/hr.po'
--- po/hr.po	2013-12-03 06:16:42 +0000
+++ po/hr.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/hu.po'
--- po/hu.po	2014-01-06 05:05:30 +0000
+++ po/hu.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-06 05:05+0000\n"
-"X-Generator: Launchpad (build 16877)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/id.po'
--- po/id.po	2013-12-03 06:16:42 +0000
+++ po/id.po	2014-02-12 06:24:20 +0000
@@ -8,27 +8,27 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-09-26 06:53+0000\n"
+"PO-Revision-Date: 2014-02-11 09:43+0000\n"
 "Last-Translator: Dirgita <Unknown>\n"
 "Language-Team: Indonesian <id@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-12 06:24+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../EventBubble.qml:38
 msgid "hh:mm"
-msgstr ""
+msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
 #: ../EventBubble.qml:43
 #, qt-format
 msgid "%1 - %2"
-msgstr ""
+msgstr "%1 - %2"
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
@@ -64,15 +64,15 @@
 
 #: ../NewEvent.qml:156
 msgid "Invite People"
-msgstr ""
+msgstr "Undang Kenalan"
 
 #: ../NewEvent.qml:168
 msgid "Error"
-msgstr ""
+msgstr "Galat"
 
 #: ../NewEvent.qml:171 ../TimePicker.qml:82
 msgid "OK"
-msgstr ""
+msgstr "Oke"
 
 #: ../NewEvent.qml:177
 msgid "Save"
@@ -80,29 +80,29 @@
 
 #: ../NewEvent.qml:205
 msgid "End time can't be before start time"
-msgstr ""
+msgstr "Waktu akhir tak mungkin sebelum waktu mulai"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "hh ap"
 
 #: ../TimePicker.qml:23
 msgid "Time"
-msgstr ""
+msgstr "Waktu"
 
 #: ../TimePicker.qml:49
 msgid "Hour"
-msgstr ""
+msgstr "Jam"
 
 #: ../TimePicker.qml:63
 msgid "Minute"
-msgstr ""
+msgstr "Menit"
 
 #: ../TimePicker.qml:73
 msgid "Cancel"
-msgstr ""
+msgstr "Batal"
 
 #: ../calendar.qml:56
 msgid "New Event"
@@ -110,23 +110,23 @@
 
 #: ../calendar.qml:64
 msgid "Today"
-msgstr ""
+msgstr "Hari ini"
 
 #: ../calendar.qml:75
 msgid "Year"
-msgstr ""
+msgstr "Tahun"
 
 #: ../calendar.qml:95
 msgid "Month"
-msgstr ""
+msgstr "Bulan"
 
 #: ../calendar.qml:108
 msgid "Week"
-msgstr ""
+msgstr "Minggu"
 
 #: ../calendar.qml:124
 msgid "Day"
-msgstr ""
+msgstr "Hari"
 
 #: ../.build/calendar-app.desktop.js:1
 msgid "Calendar"

=== modified file 'po/it.po'
--- po/it.po	2013-12-03 06:16:42 +0000
+++ po/it.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ja.po'
--- po/ja.po	2014-01-19 05:59:41 +0000
+++ po/ja.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-19 05:59+0000\n"
-"X-Generator: Launchpad (build 16901)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ka.po'
--- po/ka.po	2013-12-03 06:16:42 +0000
+++ po/ka.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/km.po'
--- po/km.po	2013-12-03 06:16:42 +0000
+++ po/km.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ko.po'
--- po/ko.po	2013-12-03 06:16:42 +0000
+++ po/ko.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/lo.po'
--- po/lo.po	2013-12-03 06:16:42 +0000
+++ po/lo.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/lv.po'
--- po/lv.po	2013-12-03 06:16:42 +0000
+++ po/lv.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ms.po'
--- po/ms.po	2013-12-15 05:46:27 +0000
+++ po/ms.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-15 05:46+0000\n"
-"X-Generator: Launchpad (build 16869)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/my.po'
--- po/my.po	2013-12-12 05:58:35 +0000
+++ po/my.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-12 05:58+0000\n"
-"X-Generator: Launchpad (build 16869)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/nb.po'
--- po/nb.po	2013-12-03 06:16:42 +0000
+++ po/nb.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/nl.po'
--- po/nl.po	2013-12-03 06:16:42 +0000
+++ po/nl.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/pl.po'
--- po/pl.po	2013-12-03 06:16:42 +0000
+++ po/pl.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/pt.po'
--- po/pt.po	2014-01-15 06:22:22 +0000
+++ po/pt.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-01-15 06:22+0000\n"
-"X-Generator: Launchpad (build 16890)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2013-12-03 06:16:42 +0000
+++ po/pt_BR.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ro.po'
--- po/ro.po	2013-12-03 06:16:42 +0000
+++ po/ro.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ru.po'
--- po/ru.po	2013-12-03 06:16:42 +0000
+++ po/ru.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/shn.po'
--- po/shn.po	2013-12-03 06:16:42 +0000
+++ po/shn.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/sk.po'
--- po/sk.po	2013-12-03 06:16:42 +0000
+++ po/sk.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/sl.po'
--- po/sl.po	2013-12-03 06:16:42 +0000
+++ po/sl.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/sr.po'
--- po/sr.po	2013-12-03 06:16:42 +0000
+++ po/sr.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== added file 'po/st.po'
--- po/st.po	1970-01-01 00:00:00 +0000
+++ po/st.po	2014-02-14 07:48:51 +0000
@@ -0,0 +1,133 @@
+# Sotho, Southern translation for ubuntu-calendar-app
+# Copyright (c) 2014 Rosetta Contributors and Canonical Ltd 2014
+# This file is distributed under the same license as the ubuntu-calendar-app package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2014.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: ubuntu-calendar-app\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2013-09-26 07:05+0200\n"
+"PO-Revision-Date: 2014-02-13 09:04+0000\n"
+"Last-Translator: Pitso Mofokeng <pitso3000@gmail.com>\n"
+"Language-Team: Sotho, Southern <st@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2014-02-14 07:48+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../EventBubble.qml:38
+msgid "hh:mm"
+msgstr "hh:mm"
+
+#. TRANSLATORS: the first argument (%1) refers to a start time for an event,
+#. while the second one (%2) refers to the end time
+#: ../EventBubble.qml:43
+#, qt-format
+msgid "%1 - %2"
+msgstr ""
+
+#: ../EventDetails.qml:70
+msgid "Add invite"
+msgstr "Eketsa mema"
+
+#: ../EventDetails.qml:79
+msgid "Edit"
+msgstr "Hlophisa"
+
+#: ../EventDetails.qml:153
+msgid "People"
+msgstr "Batho"
+
+#: ../NewEvent.qml:23
+msgid "Create event"
+msgstr "Bopa ketsahalo"
+
+#: ../NewEvent.qml:29
+msgid "Add event name"
+msgstr "Rea ketsahalo"
+
+#: ../NewEvent.qml:102
+msgid "to"
+msgstr ""
+
+#: ../NewEvent.qml:137
+msgid "Location & People"
+msgstr "Madulo le Batho"
+
+#: ../NewEvent.qml:143
+msgid "Add Location"
+msgstr "Eketsa madulo"
+
+#: ../NewEvent.qml:156
+msgid "Invite People"
+msgstr "mema batho"
+
+#: ../NewEvent.qml:168
+msgid "Error"
+msgstr "Phoso"
+
+#: ../NewEvent.qml:171 ../TimePicker.qml:82
+msgid "OK"
+msgstr "Pesetsa"
+
+#: ../NewEvent.qml:177
+msgid "Save"
+msgstr "Boloka"
+
+#: ../NewEvent.qml:205
+msgid "End time can't be before start time"
+msgstr "nako ya qalo etla pele nako ya ho fela"
+
+#. TRANSLATORS: this is a time formatting string,
+#. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
+#: ../TimeLineBackground.qml:18
+msgid "hh ap"
+msgstr "hora motsotso"
+
+#: ../TimePicker.qml:23
+msgid "Time"
+msgstr "Nako"
+
+#: ../TimePicker.qml:49
+msgid "Hour"
+msgstr "Hora"
+
+#: ../TimePicker.qml:63
+msgid "Minute"
+msgstr "Motsotso"
+
+#: ../TimePicker.qml:73
+msgid "Cancel"
+msgstr "phomola"
+
+#: ../calendar.qml:56
+msgid "New Event"
+msgstr "Ketsahalo e Ntjha"
+
+#: ../calendar.qml:64
+msgid "Today"
+msgstr "Kajeno"
+
+#: ../calendar.qml:75
+msgid "Year"
+msgstr "Selemo"
+
+#: ../calendar.qml:95
+msgid "Month"
+msgstr "Kgwedi"
+
+#: ../calendar.qml:108
+msgid "Week"
+msgstr "Beke"
+
+#: ../calendar.qml:124
+msgid "Day"
+msgstr "Letsatsi"
+
+#: ../.build/calendar-app.desktop.js:1
+msgid "Calendar"
+msgstr ""

=== modified file 'po/sv.po'
--- po/sv.po	2013-12-03 06:16:42 +0000
+++ po/sv.po	2014-02-16 06:42:38 +0000
@@ -8,14 +8,14 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2013-09-26 07:05+0200\n"
-"PO-Revision-Date: 2013-07-03 21:18+0000\n"
-"Last-Translator: Emanuel Enberg <isakemanuel@gmail.com>\n"
+"PO-Revision-Date: 2014-02-15 11:54+0000\n"
+"Last-Translator: Daniel Holm <d.holmen@gmail.com>\n"
 "Language-Team: Swedish <sv@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-16 06:42+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
@@ -32,7 +32,7 @@
 
 #: ../EventDetails.qml:70
 msgid "Add invite"
-msgstr ""
+msgstr "Lägg till inbjudan"
 
 #: ../EventDetails.qml:79
 msgid "Edit"
@@ -44,19 +44,19 @@
 
 #: ../NewEvent.qml:23
 msgid "Create event"
-msgstr ""
+msgstr "Skapa händelse"
 
 #: ../NewEvent.qml:29
 msgid "Add event name"
-msgstr ""
+msgstr "Lägg till namn på händelse"
 
 #: ../NewEvent.qml:102
 msgid "to"
-msgstr ""
+msgstr "till"
 
 #: ../NewEvent.qml:137
 msgid "Location & People"
-msgstr ""
+msgstr "Plats & Person"
 
 #: ../NewEvent.qml:143
 msgid "Add Location"

=== modified file 'po/ta.po'
--- po/ta.po	2013-12-03 06:16:42 +0000
+++ po/ta.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/te.po'
--- po/te.po	2013-12-03 06:16:42 +0000
+++ po/te.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/tr.po'
--- po/tr.po	2013-12-13 06:43:17 +0000
+++ po/tr.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-13 06:43+0000\n"
-"X-Generator: Launchpad (build 16869)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/ug.po'
--- po/ug.po	2013-12-03 06:16:42 +0000
+++ po/ug.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/uk.po'
--- po/uk.po	2013-12-03 06:16:42 +0000
+++ po/uk.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/vi.po'
--- po/vi.po	2013-12-03 06:16:42 +0000
+++ po/vi.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/xh.po'
--- po/xh.po	2013-12-03 06:16:42 +0000
+++ po/xh.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/zh_CN.po'
--- po/zh_CN.po	2013-12-03 06:16:42 +0000
+++ po/zh_CN.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/zh_HK.po'
--- po/zh_HK.po	2013-12-03 06:16:42 +0000
+++ po/zh_HK.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'po/zh_TW.po'
--- po/zh_TW.po	2013-12-03 06:16:42 +0000
+++ po/zh_TW.po	2014-02-04 06:49:14 +0000
@@ -14,8 +14,8 @@
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2013-12-03 06:16+0000\n"
-"X-Generator: Launchpad (build 16856)\n"
+"X-Launchpad-Export-Date: 2014-02-04 06:49+0000\n"
+"X-Generator: Launchpad (build 16916)\n"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions

=== modified file 'tests/autopilot/calendar_app/tests/__init__.py'
--- tests/autopilot/calendar_app/tests/__init__.py	2014-01-28 15:31:31 +0000
+++ tests/autopilot/calendar_app/tests/__init__.py	2014-01-31 21:15:52 +0000
@@ -58,9 +58,7 @@
         #turn off the OSK so it doesn't block screen elements
         if model() != 'Desktop':
             os.system("stop maliit-server")
-            #adding cleanup step seems to restart service immeadiately
-            #disabling for now
-            #self.addCleanup(os.system("start maliit-server"))
+            self.addCleanup(os.system, "start maliit-server")
 
         # Unset the current locale to ensure locale-specific data
         # (day and month names, first day of the week, …) doesn’t get

=== modified file 'tests/autopilot/calendar_app/tests/test_dayview.py'
--- tests/autopilot/calendar_app/tests/test_dayview.py	2014-01-09 23:30:55 +0000
+++ tests/autopilot/calendar_app/tests/test_dayview.py	2014-02-24 15:58:49 +0000
@@ -11,6 +11,12 @@
 
 import datetime
 
+# from __future__ import range
+# (python3's range, is same as python2's xrange)
+import sys
+if sys.version_info < (3,):
+    range = xrange
+
 from autopilot.matchers import Eventually
 from testtools.matchers import Equals, NotEquals
 
@@ -74,7 +80,7 @@
     def change_days(self, direction):
         now = datetime.datetime.now()
 
-        for i in xrange(1, 5):
+        for i in range(1, 5):
             #prevent timing issues with swiping
             old_day = self.day_view.currentDay.datetime
             self.main_view.swipe_view(direction, self.day_view)

=== modified file 'tests/autopilot/calendar_app/tests/test_weekview.py'
--- tests/autopilot/calendar_app/tests/test_weekview.py	2014-01-09 23:30:55 +0000
+++ tests/autopilot/calendar_app/tests/test_weekview.py	2014-02-24 15:58:49 +0000
@@ -9,6 +9,12 @@
 Calendar app autopilot tests for the week view.
 """
 
+# from __future__ import range
+# (python3's range, is same as python2's xrange)
+import sys
+if sys.version_info < (3,):
+    range = xrange
+
 import datetime
 
 from autopilot.matchers import Eventually
@@ -70,7 +76,8 @@
 
     def _get_date_label_headers(self):
         header = self.main_view.select_single(objectName="weekHeader")
-        timeline = header.select_many("TimeLineHeaderComponent")[0]
+        timeline = header.select_single("TimeLineHeaderComponent",
+                                        isCurrentItem=True)
         dateLabels = timeline.select_many("Label", objectName="dateLabel")
         return dateLabels
 
@@ -125,7 +132,7 @@
 
         first_dow = self._get_first_day_of_week()
 
-        for i in xrange(7):
+        for i in range(7):
             current_day = days[i]
             expected_day = (first_dow + datetime.timedelta(days=i)).day
 
@@ -140,10 +147,10 @@
 
     def test_show_next_weeks(self):
         """It must be possible to show next weeks by swiping the view."""
-        for i in xrange(6):
+        for i in range(6):
             self._change_week(1)
 
     def test_show_previous_weeks(self):
         """It must be possible to show previous weeks by swiping the view."""
-        for i in xrange(6):
+        for i in range(6):
             self._change_week(-1)

=== modified file 'tests/autopilot/calendar_app/tests/test_yearview.py'
--- tests/autopilot/calendar_app/tests/test_yearview.py	2014-01-09 23:28:15 +0000
+++ tests/autopilot/calendar_app/tests/test_yearview.py	2014-02-24 15:58:49 +0000
@@ -9,8 +9,13 @@
 Calendar app autopilot tests for the year view.
 """
 
+# from __future__ import range
+# (python3's range, is same as python2's xrange)
+import sys
+if sys.version_info < (3,):
+    range = xrange
+
 from datetime import datetime
-
 from autopilot.matchers import Eventually
 from testtools.matchers import Equals, NotEquals
 
@@ -28,13 +33,19 @@
 
         self.year_view = self.main_view.get_year_view()
 
+    def get_current_year(self):
+        return self.year_view.select_single("QQuickGridView",
+                                            isCurrentItem=True)
+
     def test_selecting_a_month_switch_to_month_view(self):
         """It must be possible to select a month and open the month view."""
 
         # TODO: the component indexed at 1 is the one currently displayed,
         # investigate a way to validate this assumption visually.
-        year_grid = self.year_view.select_many("QQuickGridView")[0]
+        year_grid = self.get_current_year()
+        self.assertThat(year_grid, NotEquals(None))
         months = year_grid.select_many("MonthComponent")
+        months.sort(key=lambda month: month.monthDate)
         self.assert_current_year_is_default_one(months[0])
 
         february = months[1]
@@ -48,7 +59,11 @@
 
         month_view = self.main_view.get_month_view()
         self.assertThat(month_view.visible, Eventually(Equals(True)))
-        selected_month = month_view.select_many("MonthComponent")[0]
+
+        selected_month = month_view.select_single("MonthComponent",
+                                                  isCurrentItem=True)
+
+        self.assertThat(selected_month, NotEquals(None))
 
         self.assertThat(self.main_view.get_year(selected_month),
                         Equals(expected_year))
@@ -87,7 +102,7 @@
     def change_year(self, direction, how_many=5):
         current_year = datetime.now().year
 
-        for i in xrange(1, how_many):
+        for i in range(1, how_many):
             #prevent timing issues with swiping
             self.main_view.swipe_view(direction, self.year_view)
 
@@ -108,13 +123,13 @@
         if now.month > 6:
             self.drag_page_up()
 
-        year_grid = self.year_view.select_many("QQuickGridView")[0]
+        year_grid = self.get_current_year()
+        self.assertThat(year_grid, NotEquals(None))
         months = year_grid.select_many("MonthComponent")
 
         for month in months:
             current_month_label = month.select_single(
                 "Label", objectName="monthLabel")
-
             if current_month_name == current_month_label.text:
                 return month
 

